@@ -1,7 +1,5 @@
 import six
 
-from six.moves import map
-
 from django import forms
 from django.conf import settings
 from django.core.exceptions import ValidationError
@@ -30,10 +28,10 @@ class CropDusterWidget(GenericForeignFileWidget):
     template = "cropduster/custom_field.html"
 
     class Media:
-        css = {'all': (u'%scropduster/css/cropduster.css?v=5' % settings.STATIC_URL,)}
+        css = {'all': (u'%scropduster/css/cropduster.css?v=6' % settings.STATIC_URL,)}
         js = (
             u'%scropduster/js/jsrender.js' % settings.STATIC_URL,
-            u'%scropduster/js/cropduster.js?v=6' % settings.STATIC_URL,
+            u'%scropduster/js/cropduster.js?v=7' % settings.STATIC_URL,
         )
 
     def get_context_data(self, name, value, attrs=None, bound_field=None):
@@ -155,7 +153,7 @@ class CropDusterInlineFormSet(BaseGenericFileInlineFormSet):
             # These can differ from the values in the database if a
             # ValidationError elsewhere prevented saving.
             try:
-                thumb_pks = map(int, form['thumbs'].value())
+                thumb_pks = [int(v) for v in form['thumbs'].value()]
             except (TypeError, ValueError):
                 pass
             else:
